@@ -55,7 +55,7 @@ class UsersAndGroup(object):
         else:
             raise SAMBAUserException("sam ldb database %s not found" % LDB_SAM_FILE)
         self.mc = memcache.Client(['127.0.0.1:11211'], debug=0)
-        config = configparser.ConfigParser()
+        config = configparser.ConfigParser(delimiters=('='))
         config.read('/etc/samba/smb.conf')
         self.domain = config['global']['workgroup'].lower()
 
