@@ -80,16 +80,8 @@ class ShareManager(object):
 if __name__ == '__main__':
     import copy
     s = ShareManager()
-    for key in s.listShares():
-        print(key)
-    home = s.getShare('homes')
-    print(home)
-    b = 'yes'
-    if home['smb'].options['browseable'] == 'yes':
-        b = 'no'
-    home['smb'].options['browseable'] = b
-    print(home)
-    print(s.writeShare(home))
+    print(s.listShares())
+
     # print(s.fromJson(
     #     {"Media": {"nfs": {"write_hosts": ["localhost", "192.168.1.1"], "read_hosts": ["192.168.106.0/24"]},"afp": {"valid_users": ["stephan"], "invalid_groups": [], "invalid_users": [], "valid_groups": []}, "path": "/media"}}
     # )
